@@ -122,7 +122,10 @@ class ScriptPythonTaskHandler(ITaskHandler,ISimpleOutputer, ICacheAbleHandler):
         :return:
         """
         # 这里动态的加载script源文件
-        instance = ScriptPythonFactory.load_instance(f"ScriptPython{self.job_id}", self.script_source,"IHandler")
+        instance = ScriptPythonFactory.load_instance(f"ScriptPython{self.job_id}", self.script_source, "IHandler",
+                                                     dataCrawl.environments if 'environments' in dataCrawl else None)
+        if "environments" in dataCrawl:
+            instance.__environments__ = dataCrawl.environments
 
         if instance.handler_enum() == HandlerEnum.NORMAL:
             return self.__inner_do_normal_crawl(instance,params)
@@ -138,7 +141,8 @@ class ScriptPythonTaskHandler(ITaskHandler,ISimpleOutputer, ICacheAbleHandler):
         """
 
         # 这里动态的加载script源文件
-        instance = ScriptPythonFactory.load_instance(f"ScriptPython{self.job_id}", self.script_source,"IHandler")
+        instance = ScriptPythonFactory.load_instance(f"ScriptPython{self.job_id}", self.script_source, "IHandler",
+                                                     dataComputeExecution.environments if 'environments' in dataComputeExecution else None)
 
         if instance.handler_enum() == HandlerEnum.NORMAL:
             return self.__inner_do_normal_compute_execution(instance, params)
